@@ -60,7 +60,7 @@ class SimpleExp3(SimpleExp):
     between tokens"""
     def __init__(self,no_table=0, table='saexp.tab'):
         grammar = """ 
-                E -> E + T {{ "Sum($0,$2)"}};
+                E -> E + T {{ "sum([$0,$2])"}};
                 E ->T ;
                 T -> T * F" {{ self.Mul }};
                 T -> F ;
