@@ -49,7 +49,7 @@ import osets
 
 _DEBUG=0
 
-_Version = "1.9.3"
+_Version = "1.9.4"
 
 NIL = ""
 
@@ -179,6 +179,8 @@ class YappyError(Exception):
     """Class for all Yappy exceptions"""
     pass
 
+class StackUnderflow(YappyError):
+    pass
 
 class LexicalError(YappyError):
     """Class for all Yappy Lexical analyser exceptions"""
@@ -1969,14 +1971,14 @@ class Stack:
 
     def pop(self):
         if not self.stack:
-            raise 'stack underflow'
+            raise StackUnderflow()
         top, self.stack = self.stack[0], self.stack[1:]
         return top
 
     def top(self):
         """ Returns top of stack (not poping it)"""
         if not self.stack: 
-            raise 'stack underflow'
+            raise StackUnderflow()
         return self.stack[0]
 
     def empty(self):
